from ..database.database import oAuthDatabase
import praw


class BaseOAuth(object):
    def __init__(self, __description__, __version__, __author__, __botname__):
        self.USR_AGNT = __description__ + " v" + __version__ + " by " + __author__

    def login(self):
        r = praw.Reddit(user_agent=self.USR_AGNT,
                        client_id=self.APP_ID,
                        client_secret=self.APP_SECRET,
                        username=self.UNAME,
                        password=self.PASSWD)

        return r

    def set_info(self, id, secret, username, password):
        self.APP_ID, self.APP_SECRET, self.UNAME, self.PASSWD = id, secret, username, password


class oAuth(object):
    def __init__(self):
        self.db = None
        self.usernames = None
        self.accounts = None

    def get_accounts(self, id, __description__, __version__, __author__, __botname__, dbusername, dbpassword, dbhost, dbname):
        self.db = oAuthDatabase(dbusername, dbpassword, dbhost, dbname)
        self.usernames = self.db.get_accounts(id)

        self.accounts = []
        for i in self.usernames:
            x = BaseOAuth(__description__, __version__, __author__, __botname__)
            x.set_info(*i)
            self.accounts.append(x)



import os
import json


class LoggerConfig(object):
    def __init__(
        self,
        __dsn__=None,
        __app_name__="_DefaultName",
        __version__="0.0.0",
        logspath="/opt/skynet/RedditBots/logs/",
        raven=True,
    ):

        configfilepath = os.path.join(os.path.dirname(__file__), "logging_config.json")
        with open(configfilepath, "rt") as f:
            self.config = json.load(f)

        # Replaces the filename with one specific to each bot
        try:
            self.config["handlers"]["rotateFileHandler"][
                "filename"
            ] = f"{logspath}_DefaultName_Logs.log".replace(
                "_DefaultName", __app_name__.replace(" ", "_")
            )
        except Exception:
            raise AttributeError("Unable to set normal logging configuration location")

        try:
            self.config["handlers"]["rotateFileHandler_debug"][
                "filename"
            ] = f"{logspath}_DefaultName_Logs_Debug.log".replace(
                "_DefaultName", __app_name__
            )
        except Exception:
            raise AttributeError("Unable to set debug logging configuration location")

        # If Raven (legacy) Sentry.io handler is enabled, set that config up
        if raven:
            # Add the Sentry handler:
            self.config["handlers"]["SentryHandler"] = {
                "level": "ERROR",
                "class": "raven.handlers.logging.SentryHandler",
                "dsn": __dsn__,
                "release": __version__,
            }

            # Enable the Sentry Handler in the main handlers
            self.config["loggers"]["root"]["handlers"] = [
                "consoleHandler",
                "rotateFileHandler",
                "rotateFileHandler_debug",
                "SentryHandler",
            ]

    def get_config(self):
        return self.config



from setuptools import setup

__app_name__ = "Layer-7-Utilities"
__description__ = "This is a set of utilities used by https://Layer7.Solutions for the software tools we create. It includes a logger with default configuration information we setup as well as an oAuth wrapper to be able to pull login information from a custom database."
__author__ = "Layer 7 Solutions (Mike Wohlrab)"
__version__ = "1.2.11"

with open("ReadMe.md", "r") as fh:
    long_description = fh.read()

setup(
    name=__app_name__,
    version=__version__,
    description=__description__,
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://Layer7.Solutions",
    author=__author__,
    author_email="Mike@Layer7.Solutions",
    license="MIT",
    packages=[
        "layer7_utilities",
        "layer7_utilities.logger",
        "layer7_utilities.exceptions",
        "layer7_utilities.database",
        "layer7_utilities.auth",
    ],
    install_requires=["psycopg2>=2.7.7", "sentry-sdk>=0.7.0", "praw>=6.1.1"],
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
    ],
)
